<?php

/*
 Plugin Name: GITST CUSTOM AVATAR
 Plugin URI: http://gitst.com/
 Description: This plugin allowes to set custom AVATAR for users. Avatar is stored in database or in custom file location : use gitst_set_avatar shortcode to display avatar set option. if you have any sugestions to improve this softare please contact GITST Team. In GITST site you can find other free software as well  * This will override the WordPress get_avatar hook. This pligin will create gitst_avatar table in database. Note: Deleting Avatar plugin will not delete gitst_avatar table from database. Note: Avatar stored into database as base64 file. Note: If you have any sugestion to improve plugging pleaes contact gitst team : info@gitst.com
 Version: 1.0.0
 Author: GITST LLC - Haykaz Kotanjyan
 Author URI: http://gitst.com/
 License: Free Licence
 */

/**
 * This program has been developed for use with the WordPress Software.
 *
 * It is distributed as free software with the intent that it will be
 * useful and does not ship with any WARRANTY.
 *
 * USAGE
 * // Default:
 * This will override the WordPress get_avatar hook
 * This pligin will create gitst_avatar table in database
 * Note: Deleting Avatar plugin will not delete gitst_avatar table from database
 * Note: Avatar stored into database as base64 file 
 * Note: If you have any sugestion to improve plugging pleaes contact gitst team : info@gitst.com
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

$gitst_avatar_editor = new GITST_AVATAR_EDITOR();


class GITST_AVATAR_EDITOR {
    
    public function __construct() {
        register_activation_hook(__FILE__,array( $this, 'gitst_activate_plugin' )  );
        
        add_action( 'delete_user',              array( $this, 'gitst_delete_user_avatar' )); 
        add_action( 'init',                     array( $this, "gitst_init_plugin" ));
        add_filter( 'get_avatar' ,              array( $this, 'gitst_avatar_default') , 1 , 5 );
        add_action( 'show_user_profile',        array( $this, 'gitst_avatar_add_admin_function'));
        add_action( 'edit_user_profile',        array( $this, 'gitst_avatar_add_admin_function'));
        add_action( 'personal_options_update',  array( $this, 'gitst_save_custom_avatar_field'));
        add_action( 'edit_user_profile_update', array( $this, 'gitst_save_custom_avatar_field'));
        
        add_shortcode("gitst_set_avatar",       array( $this, "gitst_set_avatar_function"));
        add_shortcode("gitst_display_avatar",   array( $this, "gitst_display_avatar_function"));
       
        
    }
    
    /**
* Insert or update avatar image
*/
    public function gitst_init_plugin() {
    
    global $wpdb;
    $user_id = get_current_user_id();
    if ( $user_id > 0 && isset($_FILES['gitst_avatar']) && !empty($_FILES['gitst_avatar']) && !empty( $_FILES['gitst_avatar']['tmp_name'])) {
        
        $image_name = $_FILES['gitst_avatar']['name'];
        $imgtype    = mime_content_type ( $_FILES['gitst_avatar']['tmp_name'] );
         
        if($imgtype != "image/jpg" && $imgtype != "image/png" &&$imgtype != "image/jpeg" && $imgtype != "image/gif" ) {
             echo "Sorry, only JPG, JPEG, PNG & GIF files are allowed.";
             return null;
        }
        
        
        
        $imgData    = file_get_contents( $_FILES['gitst_avatar']['tmp_name'] );
        $imgbase64  = base64_encode($imgData);   
        
        $user_avatar_table = $wpdb->prefix ."gitst_avatar"; 
        
        $querySelect = "SELECT * FROM $user_avatar_table WHERE GUID = $user_id LIMIT 1 ";
        $selResult = $wpdb->get_row($querySelect , ARRAY_A);
        
        $table_user_id = $selResult['ID'];
        
        if ($table_user_id  > 0) {
            $wpdb->update( 
                $user_avatar_table, 
                array( 
                    'GNAME' => $image_name, 
                    'GTYPE' => $imgtype, 
                    'GIMAGE'=> $imgbase64
                ), 
                array( 'ID' => $table_user_id), 
                array( 
                    '%s', 
                    '%s', 
                    '%s' 
                ) ,
                array( '%d' ) 
            );
        } else {
            $wpdb->insert( 
	        $user_avatar_table, 
                array ( 
                    'GUID'  => $user_id, 
                    'GNAME' => $image_name, 
                    'GTYPE' => $imgtype, 
                    'GIMAGE'=> $imgbase64
                ), 
                array ( 
                    '%d',
                    '%s', 
                    '%s', 
                    '%s' 
                ) 
            );
        }
    }
}

    /**
 * Is run during plugin activation and creates tables for avatar storage
 * Avatars are stored in database
 * 
 */

    function gitst_activate_plugin () {
   
   global $wpdb;
    
   $charset_collate = $wpdb->get_charset_collate();
   
   $user_avatar_table = $wpdb->prefix ."gitst_avatar"; 
   
   $create_avatar_table = "CREATE TABLE IF NOT EXISTS $user_avatar_table "  
            . " ( "
            . " ID     INTEGER PRIMARY KEY AUTO_INCREMENT, "
            . " GUID   INTEGER NOT NULL,      " 
            . " GNAME  VARCHAR(254) NOT NULL, "
            . " GTYPE  VARCHAR(254) NOT NULL, "         
            . " GIMAGE longtext NOT NULL,     "          
            . " GCDATE TIMESTAMP DEFAULT CURRENT_TIMESTAMP "  
            . ") $charset_collate;";
    
   
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($create_avatar_table);
}

    /**
 * Displayes avatar if it is in database
 */

    function gitst_avatar_default( $avatar, $id_or_email, $size, $default, $alt ){
    
    global $wpdb;
    
    if ((int)$id_or_email > 0 ) {
        
        $query = "SELECT * FROM " . $wpdb->prefix ."gitst_avatar WHERE GUID = $id_or_email LIMIT 1"  ;
        $result = $wpdb->get_results( $query, ARRAY_A);
    
        if (!empty($result)) {
            $avatar = "<img alt='" .$result[0]['GNAME']. "' src='data:". $result[0]['GTYPE'].";base64,". $result[0]['GIMAGE']. "' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
            return $avatar ;
         } else {
            return $avatar;
        } 
        
    } else if (is_string( $id_or_email )) {
        
        $user = get_user_by( 'email', $id_or_email);
        $userId = $user->ID;

        $query = "SELECT * FROM " . $wpdb->prefix ."gitst_avatar WHERE GUID = $userId  LIMIT 1"  ;
        $result = $wpdb->get_results( $query , ARRAY_A);
    
            if (!empty($result)) {
                $avatar = "<img alt='" .$result[0]['GNAME']. "' src='data:". $result[0]['GTYPE'].";base64,".$result[0]['GIMAGE']. "' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
                return  $avatar ;
            } else {
                $GLOBALS['gitst_imgid']  = 0;
                return $avatar;
            }   
        
        } else  {
         return  $avatar;
        }
    
    }

    function gitst_set_avatar_function () {
    
    $user_id = get_current_user_id();
    $htmlForm = "";
    
        if ($user_id  > 0) {
          $htmlForm  =   
                '<form action="" method="POST" enctype="multipart/form-data">'.
                    '<input type="file" name="gitst_avatar" accept="image/gif, image/jpeg, image/png"> '.
                    '<input type="submit" value="SUBMIT AVATAR"> '.
                '</form>'; 
        }
       return   $htmlForm;
    }

    function gitst_display_avatar_function ($atts) {
    
        global  $wpdb;
        $user_id = get_current_user_id();
        $htmlForm = "";
    
        if ($user_id  > 0) {
        
            
            $query = "SELECT * FROM " . $wpdb->prefix ."gitst_avatar WHERE GUID = $user_id LIMIT 1"  ;
            $result = $wpdb->get_results( $query, ARRAY_A);
    
            if (!empty($result)) {
                $htmlForm  =      "<img alt='" .$result[0]['GNAME']
                        . "' src='data:". $result[0]['GTYPE'].";base64,". $result[0]['GIMAGE']. "' "
                        . " height='" . $atts['height']. "px' "
                        . " width='" . $atts['width'] . "px' />";
            }  
          
     }
     return   $htmlForm;
}

    function gitst_avatar_add_admin_function( $user ) { ?>
<div style="border:  #aaa solid thin; padding: 20px;">
    <h3>GITST AVATAR MANAGER</h3>
    <p>javascript should be enabled for this compponent to work<br>
        Chose file and press update profile</p>
    <p>
        Shortcodes for this plugin is : <br>
        To display : [gitst_display_avatar height=150 width=150] <br>
        To Set : [gitst_set_avatar]
    </p>
	<table class="form-table">
		<tr>
		    <th>Upload/Change Avatar</th>
		    <td>
                        <input type="file" name="gitst_avatar_profile" id="gitst_avatar"  onclick="this.form.setAttribute('enctype', 'multipart/form-data')" /><br />
		    </td>
		</tr>
	</table>
     
</div>
<?php }

    function gitst_save_custom_avatar_field( $user_id ) {

       if ( !current_user_can( 'edit_user', $user_id ) ) {
            return false;
       }
     
       global $wpdb;


       if ( $user_id > 0 && isset($_FILES['gitst_avatar_profile']) && !empty($_FILES['gitst_avatar_profile']) && !empty( $_FILES['gitst_avatar_profile']['tmp_name'])) {
        
          $image_name = $_FILES['gitst_avatar_profile']['name'];
          $imgtype    = mime_content_type ( $_FILES['gitst_avatar_profile']['tmp_name'] );
          print_r($imgtype);
          
         if($imgtype != "image/jpg" && $imgtype != "image/png" &&$imgtype != "image/jpeg" && $imgtype != "image/gif" ) {
             echo "Sorry, only JPG, JPEG, PNG & GIF files are allowed.";
             return null;
         }
        
          
          
          $imgData    = file_get_contents( $_FILES['gitst_avatar_profile']['tmp_name'] );
          $imgbase64  = base64_encode($imgData);   
        
          $user_avatar_table = $wpdb->prefix ."gitst_avatar"; 
        
          $querySelect = "SELECT * FROM $user_avatar_table WHERE GUID = $user_id LIMIT 1 ";
          $selResult = $wpdb->get_row($querySelect , ARRAY_A);
        
         $table_avatar_id = $selResult['ID'];
        
         if ($table_avatar_id  > 0) {
             
            $wpdb->update( 
                $user_avatar_table, 
                array( 
                    'GNAME' => $image_name, 
                    'GTYPE' => $imgtype, 
                    'GIMAGE'=> $imgbase64
                ), 
                array( 'ID' => $table_avatar_id), 
                array( 
                    '%s', 
                    '%s', 
                    '%s' 
                ) ,
                array( '%d' ) 
            );
        } else {
            $wpdb->insert( 
	        $user_avatar_table, 
                array ( 
                    'GUID'  => $user_id, 
                    'GNAME' => $image_name, 
                    'GTYPE' => $imgtype, 
                    'GIMAGE'=> $imgbase64
                ), 
                array ( 
                    '%d',
                    '%s', 
                    '%s', 
                    '%s' 
                ) 
            );
        }
    }        
}

    function gitst_delete_user_avatar ($user_id) {
    global $wpdb;
    $user_avatar_table = $wpdb->prefix ."gitst_avatar"; 

    $wpdb->delete( 
            $user_avatar_table , 
            array( 'GUID' =>$user_id), 
            array( '%d' ) 
            );
    
    }
    

}

